@@ -1,6 +1,4 @@
 from dez.network.client import SocketClient
-from dez.http.client import HTTPClientRequest, HTTPClient
-from dez.http.server import HTTPDaemon, HTTPResponse, RawHTTPResponse
 from dez.http.client.response import HTTPClientReader
 
 client = SocketClient()
@@ -19,7 +17,7 @@ def body_cb(data, conn, request):
     if not data:
         reader = HTTPClientReader(conn)
         reader.get_headers_only(response_headers_cb, [reader, request])
-    else:    
+    else:
         conn.write(data)
 
 def response_headers_cb(response, reader, request):
@@ -28,9 +26,13 @@ def response_headers_cb(response, reader, request):
         request.write('%s: %s\r\n' % (val, response.headers[key]))
     request.write('\r\n')
     reader.get_body_stream(response_body_cb, [ request])
-    
-def response_body_cb(response, size, request):
-    if size == 0:
+
+def response_body_cb(response, request):
+    data = response.body.get_value()
+    if 'content-length' not in response.headers:
+        request.write("%X\r\n%s\r\n"%(len(data),data))
+    if not len(data):
         return request.end()
-    request.write(response.body.get_value())
+    if 'content-length' in response.headers:
+        request.write(data)
     response.body.reset()
\ No newline at end of file
