@@ -7,16 +7,16 @@ class SocketClient(object):
     def __init__(self):
         self.pools = {}
 
-    def get_connection(self, host, port, cb, args=[], eb=None, ebargs=None, timeout=60):
+    def get_connection(self, host, port, cb, args=[], eb=None, ebargs=None, timeout=60, max_conn=5):
         addr = host, port
         if addr not in self.pools:
-            self.pools[addr] = ConnectionPool(*addr)
+            self.pools[addr] = ConnectionPool(host, port, max_conn)
         self.pools[addr].get_connection(cb, args, timeout)
 
-    def start_connections(self, host, port, num, cb, args=[], timeout=None):
+    def start_connections(self, host, port, num, cb, args=[], timeout=None, max_conn=5):
         addr = host, port
         if addr not in self.pools:
-            self.pools[addr] = ConnectionPool(*addr)
+            self.pools[addr] = ConnectionPool(host, port, max_conn)
         self.pools[addr].start_connections(num, cb, args, timeout)
 
 #    def connect(self,hostname,port,cb=None):
