@@ -12,6 +12,10 @@ def parse_input():
     parser.add_option("-s", "--strict", action="store_true", dest="strict", default=False, help="(event listener) _only_ try specified notification method")
     return parser.parse_args()[0]
 
+def error(msg):
+    print "error:",msg
+    print 'type "dez_test -h" for help'
+
 def main():
     options = parse_input()
     rel.override()
@@ -26,21 +30,17 @@ def main():
     try:
         testport = int(options.port)
     except:
-        print 'error: non-integer port specified'
-        return
+        return error('non-integer port specified')
     if not options.module:
-        print "--module is required field"
-        return
+        return error("--module is required field")
     testfile = options.module
     testfunc = options.function
     try:
         testmod = __import__("dez.samples.%s"%testfile,fromlist=["dez","samples"])
     except ImportError:
-        print "invalid module specified"
-        return
+        return error("invalid module specified")
     if not hasattr(testmod, testfunc):
-        print "invalid function specified"
-        return
+        return error("invalid function specified")
     testdomain = options.domain
     print 'running %s:%s on http://%s:%s'%(testfile,testfunc,testdomain,testport)
     getattr(testmod,testfunc)(domain=testdomain,port=testport)
\ No newline at end of file
